Module: Puppet
- Defined in:
- lib/puppet_blacksmith/modulefile.rb
Overview
Avoid loading everything Puppet when we only need the module tool It causes trouble running it from jruby warbled jars
Class Method Summary collapse
Class Method Details
.[](param) ⇒ Object
7 8 |
# File 'lib/puppet_blacksmith/modulefile.rb', line 7 def self.[](param) end |
.settings ⇒ Object
4 5 6 |
# File 'lib/puppet_blacksmith/modulefile.rb', line 4 def self.settings {} end |